define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "今四半期",
	"field-quarter-short-relative+1": "翌四半期",
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"dateFormatItem-MEEEEd": "M/d(EEEE)",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+0": "今週の木曜",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "来週",
	"dateFormatItem-EBhms": "BK:mm:ss (E)",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-era-short": "時代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "来年",
	"field-tue-relative+1": "来週の火曜日",
	"field-weekdayOfMonth": "月の曜日番号",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "M月d日",
	"field-weekdayOfMonth-narrow": "月の曜日番号",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "来週",
	"field-month-relative+1": "来月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"dateFormatItem-yyyyQQQ": "Gy/QQQ",
	"field-weekOfMonth": "月の週番号",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "Gy年M月d日(E)",
	"dateFormatItem-yyyyMd": "GGGGGy/M/d",
	"field-day": "日",
	"field-dayOfYear-short": "年の通日",
	"field-year-relative+-1": "昨年",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"dateFormatItem-yyyyMEd": "GGGGGy/M/d(E)",
	"field-wed-relative+-1": "先週の水曜日",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"dateFormatItem-Ehms": "aK:mm:ss (E)",
	"dateFormat-long": "Gy年M月d日",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"dateFormatItem-MMMEEEEd": "M月d日(EEEE)",
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "M月",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"dateFormat-medium": "GGGGGy/MM/dd",
	"dateFormatItem-yyyyMMMM": "Gy年M月",
	"dateFormatItem-EEEEd": "d日(EEEE)",
	"dateFormatItem-yyyyM": "GGGGGy/M",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-2": "一昨日",
	"field-quarter-relative+-1": "前四半期",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"field-dayperiod-narrow": "午前/午後",
	"field-week-narrow-relative+-1": "先週",
	"field-dayOfYear": "年の通日",
	"field-sat-relative+-1": "先週の土曜日",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "時",
	"dateFormat-full": "Gy年M月d日(EEEE)",
	"field-month-relative+-1": "先月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"dateFormatItem-EBhm": "BK:mm (E)",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "来月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"field-quarter-short-relative+-1": "前四半期",
	"dateFormatItem-Ehm": "aK:mm (E)",
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"dateFormat-short": "GGGGGy/M/d",
	"dateFormatItem-Bh": "BK時",
	"field-year-narrow-relative+-1": "昨年",
	"field-thu-short-relative+-1": "先週の木曜",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日(E)",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H時",
	"field-weekOfMonth-short": "月の週番号",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"dateFormatItem-yyyy": "Gy年",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+0": "今週の水曜",
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "aK:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-quarter-narrow-relative+0": "今四半期",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"field-quarter-narrow-relative+1": "翌四半期",
	"dateFormatItem-h": "aK時",
	"dateFormatItem-yyyyMEEEEd": "GGGGGy/M/d(EEEE)",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "来週",
	"field-dayOfYear-narrow": "通日",
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "来月",
	"field-weekdayOfMonth-short": "月の曜日番号",
	"dateFormatItem-MEd": "M/d(E)",
	"field-zone-narrow": "タイムゾーン",
	"dateFormatItem-y": "Gy年",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"dateFormatItem-hms": "aK:mm:ss",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"field-week": "週",
	"dateFormatItem-Ed": "d日(E)",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"dateFormatItem-yyyyMMMEEEEd": "Gy年M月d日(EEEE)",
	"field-quarter-narrow-relative+-1": "前四半期",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"field-dayperiod-short": "午前/午後",
	"field-year-short-relative+1": "来年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"field-week-short-relative+-1": "先週",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"field-hour-short": "時",
	"field-zone-short": "タイムゾーン",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "来年",
	"field-era-narrow": "時代",
	"field-fri-relative+-1": "先週の金曜日",
	"dateFormatItem-Bhms": "BK:mm:ss",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "今週の月曜",
	"dateFormatItem-EHm": "H:mm (E)",
	"field-mon-narrow-relative+1": "来週の月曜",
	"dateFormatItem-GyMMMEEEEd": "Gy年M月d日(EEEE)",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"dateFormatItem-MMMEd": "M月d日(E)",
	"field-weekOfMonth-narrow": "月の週番号",
	"dateFormatItem-EHms": "H:mm:ss (E)",
	"field-weekday-narrow": "曜日",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"field-day-relative+-2": "一昨日",
	"field-weekday-short": "曜日",
	"dateFormatItem-Bhm": "BK:mm",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"dateFormatItem-Gy": "Gy年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜"
}
//end v1.x content
);